import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { CLASS, COLORS, DESIGNS, ICON_POSITIONS, GROUP_POSITIONS, MODIFIERS, OWN_PROPS, SIZES, TYPES } from './config';
import Button from './Button';
import ButtonIcon from './ButtonIcon';

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _objectSpread2;

    return _objectSpread({}, res, (_objectSpread2 = {}, _objectSpread2[key] = CLASS + "--" + key + sufix, _objectSpread2));
  }, {});
};

var CLASSES = createClasses([].concat(TYPES, DESIGNS, SIZES, MODIFIERS, ['empty']));
var COLOR_CLASSES = createClasses(COLORS, 'Color');
/**
 * Get props cleaning out AtomButton own props
 * @param  {Object} props
 * @return {Object}
 */

var cleanProps = function cleanProps(props) {
  var newProps = _objectSpread({}, props);

  OWN_PROPS.forEach(function (key) {
    return delete newProps[key];
  });
  return newProps;
};
/**
 * Get modifiers to apply according to props
 * @param  {Object} props
 * @return {Array<String>}
 */


var getModifiers = function getModifiers(props) {
  return Object.keys(props).filter(function (name) {
    return props[name] && MODIFIERS.includes(name);
  });
};

var getPropsWithDefaultValues = function getPropsWithDefaultValues(props) {
  var color = props.color,
      design = props.design,
      type = props.type; // if color or design are defined, use them with the passed or default value

  if (color || design) {
    color = color || 'primary';
    design = design || 'solid';
  } else {
    type = type || 'primary';
  }

  return _objectSpread({
    color: color,
    design: design,
    type: type
  }, props);
};

var AtomButton = function AtomButton(props) {
  var _getPropsWithDefaultV = getPropsWithDefaultValues(props),
      color = _getPropsWithDefaultV.color,
      children = _getPropsWithDefaultV.children,
      className = _getPropsWithDefaultV.className,
      groupPosition = _getPropsWithDefaultV.groupPosition,
      leftIcon = _getPropsWithDefaultV.leftIcon,
      rightIcon = _getPropsWithDefaultV.rightIcon,
      size = _getPropsWithDefaultV.size,
      design = _getPropsWithDefaultV.design,
      title = _getPropsWithDefaultV.title,
      type = _getPropsWithDefaultV.type;

  var classNames = cx(CLASS, !type && COLOR_CLASSES[color], !type && CLASSES[design], type && CLASSES[type], groupPosition && CLASS + "-group " + CLASS + "-group--" + groupPosition, size && CLASSES[size], getModifiers(props).map(function (key) {
    return CLASSES[key];
  }), !children && CLASSES.empty, className);
  var newProps = cleanProps(props);
  return React.createElement(Button, Object.assign({}, newProps, {
    className: classNames,
    title: title
  }), React.createElement("span", {
    className: CLASS + "-inner"
  }, React.createElement(ButtonIcon, {
    position: ICON_POSITIONS.LEFT,
    size: size
  }, leftIcon), leftIcon || rightIcon ? React.createElement("span", {
    className: CLASS + "-text"
  }, children) : children, React.createElement(ButtonIcon, {
    position: ICON_POSITIONS.RIGHT,
    size: size
  }, rightIcon)));
};

AtomButton.displayName = 'AtomButton';
export default AtomButton;
export { GROUP_POSITIONS as atomButtonGroupPositions };
export { TYPES as atomButtonTypes };
export { COLORS as atomButtonColors };